package com.ruoyi.nanjing.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.nanjing.mapper.TBdProducttypeMapper;
import com.ruoyi.nanjing.domain.TBdProducttype;
import com.ruoyi.nanjing.service.ITBdProducttypeService;
import com.ruoyi.common.core.text.Convert;

/**
 * 机种类型Service业务层处理
 * 
 * @author limy
 * @date 2021-01-22
 */
@Service
public class TBdProducttypeServiceImpl implements ITBdProducttypeService 
{
    @Autowired
    private TBdProducttypeMapper tBdProducttypeMapper;

    /**
     * 查询机种类型
     * 
     * @param ID 机种类型ID
     * @return 机种类型
     */
    @Override
    public TBdProducttype selectTBdProducttypeById(Long ID)
    {
        return tBdProducttypeMapper.selectTBdProducttypeById(ID);
    }

    /**
     * 查询机种类型列表
     * 
     * @param tBdProducttype 机种类型
     * @return 机种类型
     */
    @Override
    public List<TBdProducttype> selectTBdProducttypeList(TBdProducttype tBdProducttype)
    {
        return tBdProducttypeMapper.selectTBdProducttypeList(tBdProducttype);
    }

    /**
     * 新增机种类型
     * 
     * @param tBdProducttype 机种类型
     * @return 结果
     */
    @Override
    public int insertTBdProducttype(TBdProducttype tBdProducttype)
    {
        return tBdProducttypeMapper.insertTBdProducttype(tBdProducttype);
    }

    /**
     * 修改机种类型
     * 
     * @param tBdProducttype 机种类型
     * @return 结果
     */
    @Override
    public int updateTBdProducttype(TBdProducttype tBdProducttype)
    {
        return tBdProducttypeMapper.updateTBdProducttype(tBdProducttype);
    }

    /**
     * 删除机种类型对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTBdProducttypeByIds(String ids)
    {
        return tBdProducttypeMapper.deleteTBdProducttypeByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除机种类型信息
     * 
     * @param ID 机种类型ID
     * @return 结果
     */
    @Override
    public int deleteTBdProducttypeById(Long ID)
    {
        return tBdProducttypeMapper.deleteTBdProducttypeById(ID);
    }

    @Override
    public List<TBdProducttype> selectTBdProducttype() {
        return tBdProducttypeMapper.selectTBdProducttype();
    }
}
